@@ -2,6 +2,20 @@ class ObjectNotFoundException(Exception):
     """Object not found at the ID specified"""
     pass
 
+class VersionNotFoundException(Exception):
+    """Version not found"""
+    def __init__(self, *p, **kw):
+        self.context = (p, kw)
+    def __str__(self):
+        print " - Version not found: %s" % self.context
+
+class PartNotFoundException(Exception):
+    """Part not found"""
+    def __init__(self, *p, **kw):
+        self.context = (p, kw)
+    def __str__(self):
+        print " - Part not found: %s" % self.context
+
 class StoreNotFoundException(Exception):
     """Store not found"""
     pass
